@@ -1,4 +1,5 @@
 import datetime
+import json
 import os
 import time
 import uuid
@@ -237,6 +238,9 @@ class HttpRunner(object):
                         allure.attach(str(value["code"]), "code:", allure.attachment_type.TEXT)
                     if "msg" in value:
                         allure.attach(str(value["msg"]), "msg:", allure.attachment_type.TEXT)
+                    if value != {}:
+                        allure.attach(json.dumps(value, ensure_ascii=False), "data:",
+                                      allure.attachment_type.TEXT)
             except:
                 pass
             allure.attach(a.curl, "curl:", allure.attachment_type.TEXT)
