@@ -407,28 +407,25 @@ def execute_redis(rd: Union[Text, Dict, List], cli: Text) -> Any:
         return any(parsed_string.lower().startswith(func) is True for func in exists_func)
 
     def execute(cli, scope):
-        try:
-            if cli.lower().startswith("get("):
-                new_cli = "handler.str_get" + cli.split("get", 1)[1]
-            elif cli.lower().startswith("hget("):
-                new_cli = "handler.hash_get" + cli.split("hget", 1)[1]
-            elif cli.lower().startswith("hkeys("):
-                new_cli = "handler.hash_hkeys" + cli.split("hkeys", 1)[1]
-            elif cli.lower().startswith("set("):
-                new_cli = "handler.str_set" + cli.split("set", 1)[1]
-            elif cli.lower().startswith("hset("):
-                new_cli = "handler.hash_set" + cli.split("hset", 1)[1]
-            elif cli.lower().startswith("del("):
-                new_cli = "handler.delete" + cli.split("del", 1)[1]
-            elif cli.lower().startswith("hdel("):
-                new_cli = "handler.hash_del" + cli.split("hdel", 1)[1]
-            elif cli.lower().startswith("clean") and cli != "clean_redis":
-                new_cli = "handler.clean_redis" + cli.split("clean", 1)[1]
-            else:
-                new_cli = "handler." + cli
-            return eval(new_cli, scope)
-        except:
-            raise Exception("检测传入key是否错误")
+        if cli.lower().startswith("get("):
+            new_cli = "handler.str_get" + cli.split("get", 1)[1]
+        elif cli.lower().startswith("hget("):
+            new_cli = "handler.hash_get" + cli.split("hget", 1)[1]
+        elif cli.lower().startswith("hkeys("):
+            new_cli = "handler.hash_hkeys" + cli.split("hkeys", 1)[1]
+        elif cli.lower().startswith("set("):
+            new_cli = "handler.str_set" + cli.split("set", 1)[1]
+        elif cli.lower().startswith("hset("):
+            new_cli = "handler.hash_set" + cli.split("hset", 1)[1]
+        elif cli.lower().startswith("del("):
+            new_cli = "handler.delete" + cli.split("del", 1)[1]
+        elif cli.lower().startswith("hdel("):
+            new_cli = "handler.hash_del" + cli.split("hdel", 1)[1]
+        elif cli.lower().startswith("clean") and cli != "clean_redis":
+            new_cli = "handler.clean_redis" + cli.split("clean", 1)[1]
+        else:
+            new_cli = "handler." + cli
+        return eval(new_cli, scope)
 
     match_start_position = cli.index(":", 0)
     parsed_string = cli[match_start_position + 1:]
